@@ -24,6 +24,10 @@
 #' \code{FALSE} or in the same angle as the tree tips. Currently only horizontal spectrograms are available. 
 #' @param box Logical to control if the box around spectrograms is plotted (see \code{\link[graphics]{box}}). Default is \code{TRUE}.
 #' @param axis Logical to control if the Y and X axis of spectrograms are plotted (see \code{\link[graphics]{box}}). Default is \code{TRUE}.
+#' @param collevels A numeric vector of length 3. Specifies levels to partition the 
+#'   amplitude range of the spectrogram (in dB). The more levels the higher the
+#'   resolution of the spectrogram. Default is seq(-40, 0, 1). seq(-115, 0, 1) will produces spectrograms
+#'   similar to other acoustic analysis software packages. 
 #' @param ... Additional arguments to be passed to the internal spectrogram 
 #' creating function (\code{\link{spectrograms}}) or phylogeny plotting function (\code{\link[ape]{plot.phylo}}) for 
 #' customizing graphical output. Only rightwards phylogenies can be plotted.
@@ -98,7 +102,7 @@
 #last modification on oct-1-2018 (MAS)
 
 phylo_spectro <- function(X, tree, type = "phylogram", par.mar = rep(1, 4), size = 1, offset = 0, 
-                         path = NULL, ladder = NULL, horizontal = TRUE, axis = TRUE, box = TRUE, ...) {
+                         path = NULL, ladder = NULL, horizontal = TRUE, axis = TRUE, box = TRUE, collevels = seq(-40, 0, 5), ...) {
 
   # error message if ape is not installed
   if (!requireNamespace("ape",quietly = TRUE))
@@ -156,7 +160,7 @@ phylo_spectro <- function(X, tree, type = "phylogram", par.mar = rep(1, 4), size
  
  ## SPECTROGRAMS (save in temporary directory)  
   # save specreator call
- cll.spec <- quote(spectrograms(line = FALSE, pb = FALSE, dest.path = tempdir()))
+ cll.spec <- quote(spectrograms(line = FALSE, pb = FALSE, dest.path = tempdir(), collevels = collevels))
  
  # keep arguments in ... found in specreator
  shr.args <- argus[names(argus) %in% names(formals(spectrograms))]
