@@ -56,6 +56,7 @@
 #'    time intervals of 75\% and 25\% energy respectively (in s). See \code{\link[seewave]{acoustat}}
 #'    \item \code{time.IQR}: interquartile time range. Time range between 'time.Q25' and 'time.Q75' 
 #'    (in s). See \code{\link[seewave]{acoustat}}
+#'    \item \code{peakt}: peak time. Time (in s) at which the maximum amplitude is found in the amplitude vector. 
 #'    \item \code{skew}: skewness. Asymmetry of the frequency spectrum (see note in \code{\link[seewave]{specprop}} description) 
 #'    \item \code{kurt}: kurtosis. Peakedness of the frequency spectrum (see note in \code{\link[seewave]{specprop}} description)
 #'    \item \code{sp.ent}: spectral entropy. Energy distribution of the frequency spectrum. Pure tone ~ 0; 
@@ -95,7 +96,7 @@
 #' }
 #' @export
 #' @name spectro_analysis
-#' @details The function measures 29 acoustic parameters (if \code{fast = TRUE}) on 
+#' @details The function measures 30 acoustic parameters (if \code{fast = TRUE}) on 
 #'  each selection in the data frame. Most parameters are produced internally by 
 #'  \code{\link[seewave]{specprop}}, \code{\link[seewave]{fpeaks}}, \code{\link[seewave]{fund}},
 #'  and \code{\link[seewave]{dfreq}} from the package seewave and \code{\link[soundgen]{analyze}} 
@@ -328,6 +329,7 @@ spectro_analysis <-
     time.Q25 <- t.quartiles[1]
     time.Q75 <- t.quartiles[3]
     time.IQR <- t.quartiles[3] - t.quartiles[1]
+    peakt <- time[which.max(t.cont)]
     skew <- analysis$skewness
     kurt <- analysis$kurtosis
     sp.ent <- analysis$sh
@@ -387,6 +389,7 @@ spectro_analysis <-
         time.Q25,
         time.Q75,
         time.IQR,
+        peakt,
         skew,
         kurt,
         sp.ent,
